@@ -8,10 +8,10 @@ under the terms of the Creative Commons Attribution-NonCommercial
 The code is licensed under the MIT license.
 """
 
-from math import nan
 from copy import copy
 from datetime import datetime
 from typing import Union
+from numpy import NaN
 import pandas as pd
 from meteostat.core import Core
 
@@ -103,7 +103,7 @@ class Daily(Core):
         if self.max_age > 0 and self._file_in_cache(path):
 
             # Read cached data
-            df = pd.read_parquet(path)
+            df = pd.read_pickle(path)
 
         else:
 
@@ -117,9 +117,9 @@ class Daily(Core):
             # Validate Series
             df = self._validate_series(df, station)
 
-            # Save as Parquet
+            # Save as Pickle
             if self.max_age > 0:
-                df.to_parquet(path)
+                df.to_pickle(path)
 
         # Filter time period and append to DataFrame
         if self._start and self._end:
@@ -205,7 +205,7 @@ class Daily(Core):
             # Add columns
             for column in temp._columns[1:]:
                 # Add column to DataFrame
-                df[column] = nan
+                df[column] = NaN
 
             result = pd.concat([result, df], axis=0)
 
@@ -216,6 +216,9 @@ class Daily(Core):
         temp._data = pd.concat([temp._data, result], axis=0).groupby(
             ['station', 'time'], as_index=True).first()
 
+        # None -> NaN
+        temp._data = temp._data.fillna(NaN)
+
         # Return class instance
         return temp
 
