@@ -8,11 +8,12 @@ under the terms of the Creative Commons Attribution-NonCommercial
 The code is licensed under the MIT license.
 """
 
-from math import floor, nan
+from math import floor
 from copy import copy
 from datetime import datetime
 from typing import Union
 import pytz
+from numpy import NaN
 import pandas as pd
 from meteostat.core import Core
 
@@ -156,7 +157,7 @@ class Hourly(Core):
         if self.max_age > 0 and self._file_in_cache(path):
 
             # Read cached data
-            df = pd.read_parquet(path)
+            df = pd.read_pickle(path)
 
         else:
 
@@ -170,12 +171,12 @@ class Hourly(Core):
             # Validate Series
             df = self._validate_series(df, station)
 
-            # Save as Parquet
+            # Save as Pickle
             if self.max_age > 0:
-                df.to_parquet(path)
+                df.to_pickle(path)
 
         # Localize time column
-        if self._timezone is not None:
+        if self._timezone is not None and len(df.index) > 0:
             df = df.tz_localize(
                 'UTC', level='time').tz_convert(
                 self._timezone, level='time')
@@ -267,14 +268,23 @@ class Hourly(Core):
         for station in temp._stations:
             # Create data frame
             df = pd.DataFrame(columns=temp._columns[2:])
-            # Add time series
-            df['time'] = pd.date_range(temp._start, temp._end, freq='1H')
+            # Create data range
+            if temp._timezone is not None:
+                # Make start and end date timezone-aware
+                timezone = pytz.timezone(temp._timezone)
+                start = temp._start.astimezone(timezone)
+                end = temp._end.astimezone(timezone)
+                # Add time series
+                df['time'] = pd.date_range(
+                    start, end, freq='1H', tz=temp._timezone)
+            else:
+                df['time'] = pd.date_range(temp._start, temp._end, freq='1H')
             # Add station ID
             df['station'] = station
             # Add columns
             for column in temp._columns[2:]:
                 # Add column to DataFrame
-                df[column] = nan
+                df[column] = NaN
 
             result = pd.concat([result, df], axis=0)
 
@@ -285,6 +295,9 @@ class Hourly(Core):
         temp._data = pd.concat([temp._data, result], axis=0).groupby(
             ['station', 'time'], as_index=True).first()
 
+        # None -> NaN
+        temp._data = temp._data.fillna(NaN)
+
         # Return class instance
         return temp
 
